@@ -7,14 +7,15 @@
 #  convert ASCII set representation string into internal set object
 #
 sub asc2set {
-    local($asc, *set, $onlylevel, $notcleared) = @_;
-    local($i, $I, $internal);
+    my ($asc, $set, $onlylevel, $notcleared) = @_;
+    my ($i, $I, $internal);
 
     $set->Empty() if (($notcleared eq "") or (not $notcleared));
     if ($asc =~ m|^\d+:0:-1$|) {
         #   the string represents the empty set
         return $set;
     }
+
     #   split out the interval substrings 
     if ($asc =~ m|,|) {
         @I = split(/,/, $asc);
@@ -22,12 +23,13 @@ sub asc2set {
     else {
         @I = ($asc);
     }
+
     #   iterate over each interval and
     #   set the corresponding elements in the set
     foreach $interval (@I) {
         ($level, $from, $to) = ($interval =~ m|^(\d+):(\d+):(\d+)$|);
         next if (($onlylevel ne "") and ($level != $onlylevel)); 
-		next if ($from > $to);
+        next if ($from > $to);
         $set->Fill_Interval($from, $to);
     }
 }
